@@ -1,72 +1,47 @@
-### R code from vignette source 'IRISSeismic-intro.Rnw'
+## ----setup, include=FALSE------------------------------------------------
+knitr::opts_chunk$set(echo = TRUE)
 
-###################################################
-### code chunk number 1: IRISSeismic-intro.Rnw:93-95
-###################################################
+## ---- out.width = "600px", echo=FALSE------------------------------------
+knitr::include_graphics("rstudio-IRISSeismic.png")
+
+## ----first, results="hide"-----------------------------------------------
 library(IRISSeismic)
 iris <- new("IrisClient")
 
-
-###################################################
-### code chunk number 2: IRISSeismic-intro.Rnw:112-117
-###################################################
+## ----second, fig.height=4, fig.width=5-----------------------------------
 starttime <- as.POSIXct("2002-04-20", tz="GMT")
 endtime <- as.POSIXct("2002-04-21", tz="GMT")
 st <- getDataselect(iris,"US","OXF","","BHZ",starttime,endtime)
 length(st@traces)
 plotUpDownTimes(st, min_signal=1, min_gap=1)
 
-
-###################################################
-### code chunk number 3: IRISSeismic-intro.Rnw:128-129
-###################################################
+## ----third---------------------------------------------------------------
 getGaps(st)
 
-
-###################################################
-### code chunk number 4: IRISSeismic-intro.Rnw:135-138
-###################################################
+## ----fourth--------------------------------------------------------------
 parallelLength(st)
 parallelMax(st)
 parallelSd(st)
 
-
-###################################################
-### code chunk number 5: IRISSeismic-intro.Rnw:145-147
-###################################################
+## ----fifth---------------------------------------------------------------
 tr <- st@traces[[3]]
 tr@stats
 
-
-###################################################
-### code chunk number 6: IRISSeismic-intro.Rnw:152-153
-###################################################
+## ----sixth, fig.height=4, fig.width=6------------------------------------
 plot(tr)
 
-
-###################################################
-### code chunk number 7: IRISSeismic-intro.Rnw:175-176
-###################################################
+## ----seventh-------------------------------------------------------------
 slotNames(st)
 
-
-###################################################
-### code chunk number 8: IRISSeismic-intro.Rnw:196-199
-###################################################
+## ----eighth--------------------------------------------------------------
 class(st@url)
 class(st@requestedStarttime)
 class(st@traces)
 
-
-###################################################
-### code chunk number 9: IRISSeismic-intro.Rnw:209-210
-###################################################
+## ----ninth---------------------------------------------------------------
 slotNames(st@traces[[1]])
 
-
-###################################################
-### code chunk number 10: IRISSeismic-intro.Rnw:247-254
-###################################################
+## ----tenth---------------------------------------------------------------
 as.POSIXct("2010-02-27", tz="GMT") # good
 as.POSIXct("2010-02-27 04:00:00", tz="GMT") # good
 as.POSIXct("2010-02-27T04:00:00", tz="GMT",
@@ -75,16 +50,10 @@ as.POSIXct("2010-02-27T04:00:00", tz="GMT",
 as.POSIXct("2010-02-27") # BAD -- no timezone
 as.POSIXct("2010-02-27T04:00:00", tz="GMT") # BAD -- no formatting
 
-
-###################################################
-### code chunk number 11: IRISSeismic-intro.Rnw:269-270
-###################################################
+## ----eleventh, results="hide"--------------------------------------------
 help("IRISSeismic",package="IRISSeismic")
 
-
-###################################################
-### code chunk number 12: IRISSeismic-intro.Rnw:298-312
-###################################################
+## ----twelfth,fig.height=8, fig.width=6-----------------------------------
 starttime <- as.POSIXct("2010-02-27", tz="GMT")
 endtime <- as.POSIXct("2010-02-28", tz="GMT")
 st <- getDataselect(iris,"IU","ANMO","00","BHZ",starttime,endtime)
@@ -96,14 +65,11 @@ tr1 <- st@traces[[1]]
 tr2 <- slice(tr1, start2, end2)
 
 layout(matrix(seq(2)))        # layout a 2x1 matrix
-plot(tr1)                     # top
-plot(tr2)                     # bottom
+plot(tr1)
+plot(tr2)
 layout(1)                     # restore original layout
 
-
-###################################################
-### code chunk number 13: IRISSeismic-intro.Rnw:344-351
-###################################################
+## ----thirteenth----------------------------------------------------------
 starttime <- as.POSIXct("2002-04-20", tz="GMT")
 endtime <- as.POSIXct("2002-04-21", tz="GMT")
 st <- getDataselect(iris,"US","OXF","","BHZ",starttime,endtime)
@@ -112,10 +78,7 @@ picker <- STALTA(tr,3,30)
 threshold <- quantile(picker,0.99999,na.rm=TRUE)
 to <- triggerOnset(tr,picker,threshold)
 
-
-###################################################
-### code chunk number 14: IRISSeismic-intro.Rnw:373-383
-###################################################
+## ----fourteenth, fig.height=12, fig.width=6------------------------------
 layout(matrix(seq(3)))        # layout a 3x1 matrix
 closeup1 <- eventWindow(tr,picker,threshold,3600)
 closeup2 <- eventWindow(tr,picker,threshold,600)
@@ -127,25 +90,19 @@ plot(closeup2)
 abline(v=to, col='red', lwd=2)
 layout(1)                     # restore original layout
 
-
-###################################################
-### code chunk number 15: IRISSeismic-intro.Rnw:401-405
-###################################################
+## ----fiftheenth----------------------------------------------------------
 starttime <- as.POSIXct("2010-02-27", tz="GMT")
 endtime <- as.POSIXct("2010-02-28", tz="GMT")
 availability <- getAvailability(iris,"IU","ANMO","*","B??",starttime,endtime)
 availability
 
-
-###################################################
-### code chunk number 16: IRISSeismic-intro.Rnw:456-504
-###################################################
+## ----sixteenth, fig.height=4, fig.width=6--------------------------------
 # Open a connection to IRIS DMC webservices
 iris <- new("IrisClient")
 
 # Two days around the "Nisqually Quake"
 starttime <- as.POSIXct("2001-02-27", tz="GMT")
-endtime <- starttime + 3600 * 24 * 2
+endtime <- starttime + 3600 * 24 *2
 
 # Find biggest seismic event over these two days -- it's the "Nisqually"
 events <- getEvent(iris, starttime, endtime, minmag=5.0)
@@ -153,9 +110,9 @@ bigOneIndex <- which(events$magnitude == max(events$magnitude))
 bigOne <- events[bigOneIndex[1],]
 
 # Find US stations that are available within 10 degrees of arc of the 
-# event location during the hour after the event
+# event location during the 15 minutes after the event
 start <- bigOne$time
-end <- start + 3600
+end <- start + 900
 av <- getAvailability(iris, "US", "", "", "BHZ", start, end,
                       latitude=bigOne$latitude, longitude=bigOne$longitude,
                       minradius=0, maxradius=10)
@@ -185,7 +142,7 @@ length(st@traces)
 
 # Plot the seismic trace and mark the "P" and "S" arrival times
 tr <- st@traces[[1]]
-plot(tr, subsampling=1) # need subsmpling=1 to add vertical lines with abline()
+plot(tr, subsampling=1) # need subsampling=1 to add vertical lines with abline()
 abline(v=pArrival, col='red')
 abline(v=sArrival, col='blue')
 
